<?php

namespace Drp\ProjectHelpers\Tests\Concerns;

use PHPUnit_Framework_ExpectationFailedException;

/**
 * Class InteractsWithAlerts
 * @package Drp\ProjectHelpers
 */
trait InteractsWithAlerts
{

    /**
     * @param $level
     * @param null $message
     * @return $this
     */
    protected function seeInAlert($level, $message = null)
    {

        try {
            $this->seeInElement('.alert', ucfirst($level));

            if (!is_null($message)) {
                $this->seeInElement('.alert', $message);
            }

        } catch (PHPUnit_Framework_ExpectationFailedException $e) {

            //Sometimes we are using a POST request and are not re-directed
            //to to the page. This checks the correct flash message is set
            $this->seeInSession('flash_notification.message', $message);
            $this->seeInSession('flash_notification.level', $level == "error" ? 'danger' : $level);
        }

        return $this;

    }

    /**
     * @param null $message
     * @return $this
     */
    protected function seeSuccessAlert($message = null)
    {
        return $this->seeInAlert('success', $message);
    }

    /**
     * @param null $message
     * @return $this
     */
    protected function seeErrorAlert($message = null)
    {
        return $this->seeInAlert('error', $message);
    }

    /**
     * @return $this
     */
    protected function seeValidationAlert()
    {
        return $this->seeInAlert('error', trans('validation.error'));
    }

    /**
     * @param null $message
     * @return $this
     */
    protected function seeInfoAlert($message = null)
    {
        return $this->seeInAlert('info', $message);
    }

    /**
     * @param null $message
     * @return $this
     */
    protected function seeWarningAlert($message = null)
    {
        return $this->seeInAlert('warning', $message);
    }
}
