<?php

use Illuminate\Support\Collection;

if (!Collection::hasMacro('dd')) {
    /*
     * Dump the contents of the collection and terminate the script.
     */
    Collection::macro('dd', function () {
        dd($this);
    });
}

if (!Collection::hasMacro('dump')) {
    /*
     * Dump the arguments given followed by the collection.
     */
    Collection::macro('dump', function () {
        Collection::make(func_get_args())
            ->push($this)
            ->each(function ($item) {
                (new Dumper)->dump($item);
            });
        return $this;
    });
}

if (!Collection::hasMacro('collect')) {
    /*
     * Get a new collection from the collection by key.
     *
     * @param  mixed  $key
     * @param  mixed  $default
     *
     * @return static
     */
    Collection::macro('collect', function ($key, $default = null) {
        return new static($this->get($key, $default));
    });
}


if (!Collection::hasMacro('ifEmpty')) {
    /*
     * Execute a callable if the collection is empty, then return the collection.
     *
     * @param callable $callback
     *
     * @return \Illuminate\Support\Collection
     */
    Collection::macro('ifEmpty', function (callable $callback) {
        if ($this->isEmpty()) {
            $callback($this);
        }
        return $this;
    });
}


if (!Collection::hasMacro('fill')) {
    Collection::macro('fill', function ($value) {
        return $this->combine(array_fill(0, $this->count(), $value));
    });
}

if (!Collection::hasMacro('transpose')) {
    Collection::macro('transpose', function () {
        $items = array_map(function (...$items) {
            return $items;
        }, ...$this->values());
        return new static($items);
    });
}

if (!Collection::hasMacro('transposeWithKeys')) {
    Collection::macro('transposeWithKeys', function () {
        $items = array_map(function (...$items) {
            return array_combine($this->keys()->toArray(), $items);
        }, ...$this->values());
        return new static(array_combine(array_keys($this->first()), $items));
    });
}

if (!Collection::hasMacro('resetChunkArrayKeys')) {
    Collection::macro('resetChunkArrayKeys', function () {
        return $this->map(function ($chunk) {
            return $chunk->values();
        });
    });
}

if (!Collection::hasMacro('videoIds')) {
    Collection::macro('intersectKey', function ($data) {
        if ($data instanceof static) {
            $data = $data->toArray();
        }
        return new static(array_intersect_key($this->items, $data));
    });
}